all.Carsm<-function(){
     cat("\n")
     note_for_CBZsm_input()
     cat("\n")
     note_for_close_window()
     CBZSMMpar<-data.frame(parameter=c("TBW (kg)","PB","VPA","PHT","E","D (mg)","tau (hr)"),value=c(0))
     CBZSMMpar<-edit(CBZSMMpar)
##     CBZSMMpar<-ycheck(CBZSMMpar)
     cat("\n")
     note_for_CBZsm_conc_input()
     cat("\n")
     note_for_close_window()
     CBZSMpar<-data.frame(ts=c(0),conc=c(0))
     CBZSMpar<-edit(CBZSMpar)
     CBZSMpar<-mscheck(CBZSMpar)
     cat("\n")
     Car.sm(length(CBZSMpar$ts),CBZSMpar$conc,CBZSMpar$ts,CBZSMMpar[7,2],CBZSMMpar[6,2],CBZSMMpar[1,2],CBZSMMpar[2,2],CBZSMMpar[3,2],CBZSMMpar[4,2],CBZSMMpar[5,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_CBZsm_output()
     show(samplesStats("*"))
     cat("\n")
     C<-pocpr(1.2,CBZSMMpar[6,2],CBZSMMpar[7,2],CBZSMMpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)     
     cat("\n")
     Car.more()  
}